Fast computation of weighted design matrix for generalized linear model
weight_design_band(w, alpha, B)Vector of weights.
Vector of indexes representing the start of blocks of the design matrix, as given by block_design.
Design matrix in compressed block format, as given by block_design.
Weighted design matrix \(X^T diag(w) X\) where X is the design matrix and W = diag(w) is
a diagonal matrix of weights.